@@ -23,7 +23,7 @@ Algorithm::Easing - Calculate eased translations between two positive whole inte
 
         # this example produces traditional 'bounce' output;
 
-        my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
+        my $translation_mediator = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
 
         # total time for eased translation as a real positive integer value
         my $d = 2.5;
@@ -40,7 +40,7 @@ Algorithm::Easing - Calculate eased translations between two positive whole inte
         my @p = [319,0];
 
         for(my $t = 0; $t < 2.5; $t += 0.0625) {
-            $p[1] = $bounce_translation->ease_out($t,$b,$c,$d)
+            $p[1] = $translation_mediator->ease_out($t,$b,$c,$d)
 
             # plot
             ...
@@ -78,7 +78,7 @@ Read of a usage example using the proper mediator :
 
     # this example produces traditional 'bounce' output;
 
-    my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
+    my $translation_mediator = Algorithm::Easing::Mediator->new(Algorithm::Easing::Bounce->new);
 
     # total time for eased translation as a real positive integer value
     my $t = 2.5;
@@ -95,11 +95,61 @@ Read of a usage example using the proper mediator :
     my @p = [319,0];
 
     for(my $d = 0; $d < 2.5; $d += 0.0625) {
-        $p[1] = $bounce_translation->ease_out($t,$b,$c,$d)
+        $p[1] = $translation_mediator->ease_out($t,$b,$c,$d)
 
         # plot
-        ...
+        ...;
     }
+    
+=item ease_none()
+
+    Usage -- the expected parameters are as follows : 
+        t = time
+        b = begin
+        c = change
+        d = duration
+        
+    $obj->ease_none($t,$b,$c,$d);
+
+This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
+
+=item ease_in()
+
+    Usage -- the expected parameters are as follows : 
+        t = time
+        b = begin
+        c = change
+        d = duration
+        
+    $obj->ease_in($t,$b,$c,$d);
+
+This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
+
+=item ease_out()
+
+    Usage -- the expected parameters are as follows : 
+        t = time
+        b = begin
+        c = change
+        d = duration
+        
+    $obj->ease_out($t,$b,$c,$d);
+
+This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
+
+=item ease_both()
+
+    Usage -- the expected parameters are as follows : 
+        t = time
+        b = begin
+        c = change
+        d = duration
+        
+    $obj->ease_both($t,$b,$c,$d);
+
+This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
+
+    
         
 =head1 AUTHOR
 
@@ -112,4 +162,4 @@ Copyright 2016 by Jason McVeigh
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
